testpath: Testing utilities for filesystem-related code
=======================================================

Description
-----------

Testpath is a collection of utilities for testing code which uses and
manipulates the filesystem and system commands
